===================================
Welcome to msprime's documentation!
===================================

Simulate genealogical trees and genomic sequence data using
retrospective population genetic models.

.. todo:: This way of splitting up the content is preliminary and
    doesn't really make sense. Work in progress!

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   what_is
   quickstart
   installation

.. toctree::
   :maxdepth: 2
   :caption: Running simulations

   ancestry
   mutations
   demography
   likelihoods
   utilities

.. toctree::
   :maxdepth: 2
   :caption: API documentation

   quickref
   cli

.. toctree::
   :maxdepth: 2
   :caption: Developers

   development
   CITATION
   changelog

   tutorial
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

